def funt_kg(funty: float) -> float:
    return funty * 0.45359237


def stopy_m(stopy: float) -> float:
    return stopy * 0.3048


def cale_m(cale: float) -> float:
    return cale * 0.0254


def mile_km(mile: float) -> float:
    return mile * 1.609344


def gale_l(gale: float) -> float:
    return gale * 3.785411784


def kg_funty(kg: float) -> float:
    return kg / 0.45359237


def m_stopy(m: float) -> float:
    return m / 0.3048


def m_cale(m: float) -> float:
    return m / 0.0254


def km_mile(km: float) -> float:
    return km * 1.609344


def l_gale(litry: float) -> float:
    return litry / 3.785411784
